==> guikachu-1.1.5.tar.gz: guikachu-1.1.5/src/form-editor/scrollbar-prop.h <==
//$Id: scrollbar-prop.h,v 1.5 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_SCROLLBAR_PROP_H
#define GUIKACHU_FORM_EDITOR_SCROLLBAR_PROP_H

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ScrollBarProperties;
	}
    }
}

#include "scrollbar.h"
#include "widgets/num-entry.h"

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ScrollBarProperties: public SigC::Object
	    {
		Widgets::ScrollBar             *res;
		Gtk::Widget                    *property_editor;
		GUI::PropertyEditors::NumEntry *value, *min_value, *max_value;
	    public:
		ScrollBarProperties (Widgets::ScrollBar *res);
		~ScrollBarProperties ();
		Gtk::Widget *get_editor ();
	    private:
		void update ();
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_SCROLLBAR_PROP_H */

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/scrollbar-prop.h <==
//$Id: scrollbar-prop.h,v 1.7 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_SCROLLBAR_PROP_H
#define GUIKACHU_FORM_EDITOR_SCROLLBAR_PROP_H

#include "scrollbar.h"
#include "widget-prop.h"

#include "widgets/num-entry.h"

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ScrollBarProperties: public WidgetProperties,
				       public SigC::Object
	    {
		Widgets::ScrollBar             *res;
		Gtk::Widget                    *property_editor;
		GUI::PropertyEditors::NumEntry *value, *min_value, *max_value;

	    public:
		ScrollBarProperties (Widgets::ScrollBar *res);
		~ScrollBarProperties ();
		Gtk::Widget *get_editor ();
	    private:
		void update ();
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_SCROLLBAR_PROP_H */
